@@ -610,9 +610,11 @@ test_that("big Ns constant by page",{
                  Value = c(12, 14, 31, 20, 32, 18)
   ) %>%
     mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+
   big_ns <- data %>%
     summarise(.by = c( Column), Value = sum(Value)) %>%
     mutate(Param = "big_N")
+
   data <- bind_rows(data, big_ns)
 
   mytfrmt <- tfrmt(
@@ -726,3 +728,256 @@ test_that("big Ns constant by page",{
   )
 
 })
+
+
+
+test_that("not enough big Ns by page",{
+
+  # big Ns are constant by page
+  data <- tibble(Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+                 Label = rep("n",6),
+                 Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+                 Param = rep("n",6),
+                 Value = c(12, 14, 31, 20, 32, 18)
+  ) %>%
+    mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+
+  #remove sex bigns so we have a missmatch of big ns
+  big_ns <- data %>%
+    filter(Group=="Age (y)") %>%
+    summarise(.by = c( Column, Group), Value = sum(Value)) %>%
+    mutate(Param = "big_N")
+
+  data <- bind_rows(data, big_ns)
+
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    sorting_cols = ord1,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(group_val = ".default")
+    ),
+    big_n = big_n_structure(param_val = c("big_N"), by_page = TRUE)
+  )
+
+  expect_message(
+    auto <- mytfrmt %>%
+      apply_tfrmt(.data = data, tfrmt = ., mock = FALSE),
+    "Mismatch between big Ns and page_plan. For varying big N's by page (`by_page` = TRUE in `big_n_structure`), data must contain 1 big N value per unique grouping variable/value set to \".default\" in `page_plan`",
+    fixed = TRUE
+  )
+
+})
+
+
+test_that("Paging (group) variable is sorted non-alphabetically",{
+
+  # same sorting of data and big Ns
+  data <- tibble(Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+                 Label = rep("n",6),
+                 Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+                 Param = rep("n",6),
+                 Value = c(12, 14, 31, 20, 32, 18)
+  ) %>%
+    mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+
+  big_ns <- data %>%
+    summarise(.by = c( Column, Group), Value = sum(Value)) %>%
+    mutate(Param = "big_N")
+
+  data <- bind_rows(data, big_ns)|>
+    arrange(desc(Group))
+
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(
+        group_val = list(Group = ".default"))
+    ),
+    big_n = big_n_structure(param_val = "big_N", by_page = TRUE)
+  )
+
+  auto <- mytfrmt %>%
+    apply_tfrmt(.data = data, tfrmt = ., mock = FALSE)
+
+  #check that the labels have printed in the changed order
+  expect_equal(
+    map(auto, ~ .x[["Label"]][1]), # This extracts the first value of the "Label" column from each element
+    list(
+      "Sex",
+      "Age (y)"
+    )
+  )
+ # check big Ns have been correctly applied
+  expect_equal(
+    map(auto, names),
+    list(
+      c("Label","Placebo\nN = 20","Treatment\nN = 32","Total\nN = 18","..tfrmt_row_grp_lbl"),
+      c("Label","Placebo\nN = 12","Treatment\nN = 14","Total\nN = 31","..tfrmt_row_grp_lbl")
+    )
+  )
+
+
+
+  # different sorting of data and big Ns
+  data <- tibble(Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+                 Label = rep("n",6),
+                 Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+                 Param = rep("n",6),
+                 Value = c(12, 14, 31, 20, 32, 18)
+  ) %>%
+    mutate(ord1 = if_else(Group == "Age (y)", 1, 2)) %>%
+    arrange(desc(Group))
+
+  big_ns <- data %>%
+    summarise(.by = c( Column, Group), Value = sum(Value)) %>%
+    mutate(Param = "big_N") %>%
+    arrange(Group)
+
+  data <- bind_rows(data, big_ns)
+
+  mytfrmt <- tfrmt(
+    group = Group,
+    label = Label,
+    column = Column,
+    value = Value,
+    param = Param,
+    body_plan = body_plan(
+      frmt_structure(group_val = ".default", label_val = ".default", frmt("xx"))
+    ),
+    col_plan = col_plan(everything(), -starts_with("ord"), "Total"),
+    row_grp_plan = row_grp_plan(
+      row_grp_structure(group_val = ".default", element_block(post_space = " "))
+    ),
+    page_plan = page_plan(
+      page_structure(
+        group_val = list(Group = ".default"))
+    ),
+    big_n = big_n_structure(param_val = "big_N", by_page = TRUE)
+  )
+
+  expect_message(
+    auto <- mytfrmt %>%
+      apply_tfrmt(.data = data, tfrmt = ., mock = FALSE),
+    "Mismatch between big Ns and page_plan. For varying big N's by page (`by_page` = TRUE in `big_n_structure`), data must contain 1 big N value per unique grouping variable/value set to \".default\" in `page_plan` and bigNs must be in order of the data"
+    ,
+    fixed = TRUE
+  )
+})
+
+
+test_that("Two grouping variables with a page_plan work as expected (renamed variables with a space)", {
+
+# Create the original data frame
+original_data <- tibble(
+  Group = rep(c("Age (y)", "Sex"), c(3, 3)),
+  Label = rep("n", 6),
+  Column = rep(c("Placebo", "Treatment", "Total"), times = 2),
+  Param = rep("n", 6),
+  Value = c(12, 14, 31, 20, 32, 18)
+) %>%
+  mutate(ord1 = if_else(Group == "Age (y)", 1, 2))
+
+# Duplicate the data and add the `by group` column
+data_101 <- original_data %>% mutate(`by group` = "101")
+data_102 <- original_data %>% mutate(`by group` = "102")
+
+# Combine the two data frames
+data <- bind_rows(data_101, data_102)
+
+# Create mock big Ns
+big_ns <- data %>%
+  group_by(`by group`, Column) %>%
+  summarise(Value = sum(Value)) %>%
+  mutate(Param = "bigN") %>%
+  filter(`by group` == "101") %>%
+  ungroup()
+
+data <- bind_rows(data, big_ns)|>
+  arrange(desc(Group))
+
+# Define the tfrmt object with two grouping variables and a page_plan
+tfrmt_two_groups <- tfrmt(
+  group = c(`by group`, Group),
+  label = Label,
+  column = Column,
+  value = Value,
+  param = Param,
+  body_plan = body_plan(
+    frmt_structure(group_val = ".default", label_val = "n", frmt("xx"))
+  ),
+  row_grp_plan = row_grp_plan(
+    row_grp_structure(group_val = ".default", element_block(post_space = " "))
+  ),
+  page_plan = page_plan(
+    page_structure(
+      group_val = list(`by group` = ".default")
+    ),
+    note_loc = "subtitle"
+  ),
+  big_n = big_n_structure(param_val = "bigN"),
+  col_plan = col_plan(-`by group`)
+)
+
+# Apply the tfrmt and check the output for each page
+output_list <- tfrmt_two_groups %>%
+  apply_tfrmt(.data = data, tfrmt = ., mock = FALSE)
+
+# Expect two elements in the output list, one for each `By group` value
+expect_length(output_list, 2)
+
+# Check the order of page notes
+expect_equal(
+  map_chr(output_list, ~attr(.x, ".page_note")),
+  c("by group: 101", "by group: 102")
+)
+
+# Check the first page (`by group` = "101")
+page_1_names <- names(output_list[[1]])
+expect_equal(
+  page_1_names,
+  c(
+    "Label",
+    "ord1",
+    "Placebo\nN = 32",
+    "Treatment\nN = 46",
+    "Total\nN = 49",
+    "..tfrmt_row_grp_lbl"
+  )
+)
+
+# Check the second page (`by group` = "102")
+page_2_names <- names(output_list[[2]])
+expect_equal(
+  page_2_names,
+  c(
+    "Label",
+    "ord1",
+    "Placebo\nN = 32",
+    "Treatment\nN = 46",
+    "Total\nN = 49",
+    "..tfrmt_row_grp_lbl"
+  )
+)
+})
